@@ -17,9 +17,7 @@ Usage::
     instance_in_service_waiter: InstanceInServiceWaiter = client.get_waiter("instance_in_service")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
-from typing import List
+from typing import List, TYPE_CHECKING
 from botocore.waiter import Waiter as Boto3Waiter
 from mypy_boto3_elb.type_defs import InstanceTypeDef, WaiterConfigTypeDef
 
@@ -29,7 +27,7 @@ __all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "Instance
 
 class AnyInstanceInServiceWaiter(Boto3Waiter):
     """
-    [Waiter.AnyInstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
+    [Waiter.AnyInstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
     """
 
     def wait(
@@ -39,13 +37,13 @@ class AnyInstanceInServiceWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [AnyInstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
+        [AnyInstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
         """
 
 
 class InstanceDeregisteredWaiter(Boto3Waiter):
     """
-    [Waiter.InstanceDeregistered documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
+    [Waiter.InstanceDeregistered documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
     """
 
     def wait(
@@ -55,13 +53,13 @@ class InstanceDeregisteredWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [InstanceDeregistered.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
+        [InstanceDeregistered.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
         """
 
 
 class InstanceInServiceWaiter(Boto3Waiter):
     """
-    [Waiter.InstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
+    [Waiter.InstanceInService documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
     """
 
     def wait(
@@ -71,5 +69,5 @@ class InstanceInServiceWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [InstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.11.1/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
+        [InstanceInService.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.11/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
         """
